# frozen_string_literal: true

require 'spec_helper'

describe 'sympa' do
  on_supported_os.each do |os, os_facts|
    context "on #{os}" do
      let(:facts) { os_facts }

      it { is_expected.to compile.with_all_deps }
      it do
        is_expected.to contain_file('/home/sympa/etc/sympa_aliases.postfix') \
          .with_content(%r{^listmaster:\s+"| /home/sympa/libexec/queue listmaster@listes\.example\.org$})
      end

      context 'with manage_user false' do
        let(:params) do
          {
            manage_user: false,
          }
        end

        it { is_expected.to compile.with_all_deps }
      end

      context 'with manage_database false' do
        let(:params) do
          {
            manage_database: false,
          }
        end

        it { is_expected.to compile.with_all_deps }
      end

      context 'with only one listmaster email address' do
        let(:params) do
          {
            listmaster: ['lm1@example.com'],
          }
        end

        it { is_expected.to compile.with_all_deps }
        it do
          is_expected.to contain_file('/home/sympa/etc/sympa.conf') \
            .with_content(%r{^listmaster\s+lm1@example\.com$})
        end
      end

      context 'with several listmaster email addresses' do
        let(:params) do
          {
            listmaster: ['lm1@example.com', 'lm2@example.com'],
          }
        end

        it { is_expected.to compile.with_all_deps }
        it do
          is_expected.to contain_file('/home/sympa/etc/sympa.conf') \
            .with_content(%r{^listmaster\s+lm1@example\.com,lm2@example\.com$})
        end
      end

      context 'with empty defined topics' do
        let(:params) do
          {
            topics: {},
          }
        end

        it { is_expected.to compile.with_all_deps }
        it do
          is_expected.to contain_file('/home/sympa/etc/topics.conf') \
            .with_content(%r{^# empty topics})
        end
      end

      context 'with defined topics' do
        let(:params) do
          {
            topics: {
              'custom': {
                'fr': 'personnel',
                'en': 'custom',
              },
            },
          }
        end

        it { is_expected.to compile.with_all_deps }
        it do
          is_expected.to contain_file('/home/sympa/etc/topics.conf') \
            .with_content(%r{personnel})
        end
      end

      context 'with dkim_feature enabled and missing private key' do
        let(:params) do
          {
            dkim_feature: true,
          }
        end

        it { is_expected.to compile.and_raise_error(%r{With dkim_feature true, dkim_private_key is mandatory.}) }
      end

      context 'with dkim_feature and dmarc_protection enabled' do
        let(:params) do
          {
            dkim_feature: true,
            dkim_private_key: '/etc/sympa/foo.key',
            dmarc_protection: true,
          }
        end

        it { is_expected.to compile.with_all_deps }
        it do
          is_expected.to contain_file('/home/sympa/etc/sympa.conf') \
            .with_content(%r{^dkim_signature_apply_on\s+any$}) \
            .with_content(%r{^dmarc_protection\.mode\s+all$})
        end
      end
    end
  end
end
